import os.path
import json


def get_project_info_dict(version_config=None):
    if version_config is None:
        from django.conf import settings

        version_config = settings.VERSION_CONFIG

    if os.path.isfile(version_config):
        with open(version_config) as f:
            return json.load(f)
    else:
        return {}


def get_version(version_config=None):
    return get_project_info_dict(version_config).get('version')



from setuptools import setup, find_packages

setup(
    name='skip-django-project-info',
    version='1.0.2.1',
    description='A small plugin which takes a configuration (like Bower or npm) and it provides data via context'
    'processors.',
    keywords='django, project-info',
    author='Lukas Rychtecky',
    author_email='lukas.rychtecky@gmail.com',
    url='https://github.com/skip-pay/django-project-info',
    license='MIT',
    package_dir={'project_info': 'project_info'},
    include_package_data=True,
    packages=find_packages(),
    install_requires=[
        'django>=1.11',
    ],
    zip_safe=False
)
